secr.fit,
confint.secr, and score.test.
D.designdata (mask, Dmodel, grouplevels, sessionlevels, sessioncov =
NULL, meanSD = NULL)mask object. attr(dframe, "dimD") =
c(nmask, ngrp, R), where nmask is the number of mask points,
ngrp is the number of groups, and R is the number of
sessions. Columns correspond to predictor variables in Dmodel.The number of valid rows (points in each session-specific mask) is
stored in the attribute `validMaskRows'.For a single-session mask, meanSD is a 2 x 2 matrix of mean and
SD (rows) for x- and y-coordinates. For a multi-session mask, a list of
such objects. Ordinarily these values are from the meanSD attribute of
the mask, but they must be specified when applying a new mask to an
existing model.This is an internal secr function that you are unlikely ever to
use. Unlike secr.design.MS, this function does not
call model.matrix.
secr.design.MS